@@ -21,6 +21,7 @@
 
 #include "webengine_filter.h"
 #include <webenginepart_debug.h>
+#include "../../src/htmldefaults.h"
 
 #include <KConfig>
 #include <KSharedConfig>
@@ -34,20 +35,6 @@
 #include <QFontDatabase>
 #include <QFileInfo>
 
-// browser window color defaults -- Bernd
-#define HTML_DEFAULT_LNK_COLOR Qt::blue
-#define HTML_DEFAULT_TXT_COLOR Qt::black
-#define HTML_DEFAULT_VLNK_COLOR Qt::magenta
-#define HTML_DEFAULT_BASE_COLOR Qt::white
-
-#define HTML_DEFAULT_VIEW_FONT "Sans Serif"
-#define HTML_DEFAULT_VIEW_FIXED_FONT "Monospace"
-#define HTML_DEFAULT_VIEW_SERIF_FONT "Serif"
-#define HTML_DEFAULT_VIEW_SANSSERIF_FONT "Sans Serif"
-#define HTML_DEFAULT_VIEW_CURSIVE_FONT "Sans Serif"
-#define HTML_DEFAULT_VIEW_FANTASY_FONT "Sans Serif"
-#define HTML_DEFAULT_MIN_FONT_SIZE 7 // everything smaller is usually unreadable.
-
 /**
  * @internal
  * Contains all settings which are both available globally and per-domain
@@ -144,6 +131,7 @@ public:
     QList< QPair< QString, QChar > > m_fallbackAccessKeysAssignments;
 
     KSharedConfig::Ptr nonPasswordStorableSites;
+    bool m_internalPdfViewer;
 };
 
 class WebEngineSettingsPrivate : public QObject, public WebEngineSettingsData
@@ -311,6 +299,11 @@ bool WebEngineSettings::hoverLink() const
   return d->m_hoverLink;
 }
 
+bool WebEngineSettings::internalPdfViewer() const
+{
+    return d->m_internalPdfViewer;
+}
+
 void WebEngineSettings::init()
 {
   initWebEngineSettings();
@@ -498,6 +491,10 @@ void WebEngineSettings::init( KConfig * config, bool reset )
         d->m_userSheet.clear();
     }
 
+    if (reset || cgHtml.hasKey("InternalPdfViewer")) {
+        d->m_internalPdfViewer = cgHtml.readEntry("InternalPdfViewer", false);
+    }
+
     d->m_formCompletionEnabled = cgHtml.readEntry("FormCompletion", true);
     d->m_maxFormCompletionItems = cgHtml.readEntry("MaxFormCompletionItems", 10);
     d->m_autoDelayedActionsEnabled = cgHtml.readEntry ("AutoDelayedActions", true);
@@ -719,6 +716,10 @@ void WebEngineSettings::init( KConfig * config, bool reset )
 
   QWebEngineSettings::defaultSettings()->setAttribute(QWebEngineSettings::ScrollAnimatorEnabled, smoothScrolling() != KSmoothScrollingDisabled);
 
+#ifdef WEBENGINE_PDF_VIEWER
+  QWebEngineSettings::defaultSettings()->setAttribute(QWebEngineSettings::PdfViewerEnabled, internalPdfViewer());
+#endif
+
   // These numbers should be calculated from real "logical" DPI/72, using a default dpi of 96 for now
   computeFontSizes(96);
 }
